Welcome to tweakwcs documentation!
==================================

``tweakwcs`` is a package that provides core algorithms for computing and
applying corrections to ``WCS`` objects such as to minimize mismatch between
image and reference catalogs. Currently only aligning images with ``FITS WCS``
and ``JWST gWCS`` are supported.

.. moduleauthor:: Mihai Cara <help@stsci.edu>

Content
=======

.. toctree::
   :maxdepth: 2

   imalign
   tpwcs
   matchutils
   wcsimage
   linearfit
   wcsutils
   linalg
   LICENSE.rst


Development Notes
=================

.. toctree::
   :maxdepth: 1
   :titlesonly:

   CHANGELOG.rst


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
